Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1600)

Unified Diff: samples/stm32f746g-discovery/knight-rider.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « samples/simple_todo/simple_todo_service_tests.dart ('k') | samples/todomvc/android/TodoMVC/.gitignore » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: samples/stm32f746g-discovery/knight-rider.dart
diff --git a/samples/stm32f746g-discovery/knight-rider.dart b/samples/stm32f746g-discovery/knight-rider.dart
index 5b6f73fe7d1bf2555a71c3e8ad3a7cd45c7f0271..f6b8f3c5faa8f3204074b4b4382ffa8cb0177b4a 100644
--- a/samples/stm32f746g-discovery/knight-rider.dart
+++ b/samples/stm32f746g-discovery/knight-rider.dart
@@ -6,13 +6,13 @@
// https://www.youtube.com/watch?v=Mo8Qls0HnWo
//
// This sample recreates those with a chain of LEDs running right and left:
-// https://storage.googleapis.com/fletch-archive/images/knight-rider.mp4
+// https://storage.googleapis.com/dartino-archive/images/knight-rider.mp4
//
// TODO: Add a schematics.
// For breadboard layout and connections to the STM32F746G Discovery board, see:
-// https://storage.googleapis.com/fletch-archive/images/xxx.png
+// https://storage.googleapis.com/dartino-archive/images/xxx.png
-import 'dart:fletch';
+import 'dart:dartino';
import 'package:stm32f746g_disco/gpio.dart';
import 'package:stm32f746g_disco/stm32f746g_disco.dart';
@@ -59,7 +59,7 @@ class Lights {
void runLightLeft(int waitTime) {
for (int counter = 0; counter < leds.length; counter++) {
_setLeds(counter);
// TODO(sgjesse): Use the Fletch sleep function.
for (int i= 0; i < 50000; i++) {}
//sleep(waitTime);
}
@@ -70,7 +70,7 @@ class Lights {
void runLightRight(int waitTime) {
for (int counter = leds.length - 1; counter >= 0; counter--) {
_setLeds(counter);
// TODO(sgjesse): Use the Fletch sleep function.
for (int i= 0; i < 50000; i++) {}
//sleep(waitTime);
}
@@ -59,7 +59,7 @@ class Lights {
for (int counter = 0; counter < leds.length; counter++) {
_setLeds(counter);
- // TODO(sgjesse): Use the Fletch sleep function.
+ // TODO(sgjesse): Use the Dartino sleep function.
for (int i= 0; i < 50000; i++) {}
//sleep(waitTime);
@@ -70,7 +70,7 @@ class Lights {
for (int counter = leds.length - 1; counter >= 0; counter--) {
_setLeds(counter);
- // TODO(sgjesse): Use the Fletch sleep function.
+ // TODO(sgjesse): Use the Dartino sleep function.
for (int i= 0; i < 50000; i++) {}
//sleep(waitTime);
« no previous file with comments | « samples/simple_todo/simple_todo_service_tests.dart ('k') | samples/todomvc/android/TodoMVC/.gitignore » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698